@@ -1,8 +1,8 @@
 `inpoly` <-
   function(x,y, POK )
   {
-    ##  require splancs
-    kin = splancs::inout(cbind(x, y) ,cbind(POK$x, y =POK$y), bound=TRUE)
+    ##  
+    kin = fields::in.poly(cbind(x, y) ,cbind(POK$x, y =POK$y) )
 
     G = rep(0,length(x))
     G[kin] = 1
